@@ -110,7 +110,7 @@ class Deb822Editor(Editor[List[Deb822Paragraph], bytes]):
                  allow_reformatting: Optional[bool] = None,
                  allow_missing: bool = False,
                  accept_files_with_error_tokens: bool = False) -> None:
-        super(Deb822Editor, self).__init__(
+        super().__init__(
             path, allow_generated=allow_generated,
             allow_reformatting=allow_reformatting,
             mode='b')
