@@ -27,7 +27,7 @@ from debian.deb822 import Deb822
 
 
 def _load_vendor_file(vendor: str = 'default') -> Deb822:
-    with open('/etc/dpkg/origins/%s' % vendor, 'r') as f:
+    with open('/etc/dpkg/origins/%s' % vendor) as f:
         return Deb822(f)
 
 
