@@ -38,12 +38,10 @@ DEFAULT_USER_AGENT = 'debmutate/%s' % '.'.join([str(x) for x in __version__])
 
 DEFAULT_VERSION: int = 4
 
-# TODO(jelmer): Add support for substitution variables:
-
 SUBSTITUTIONS = {
     # This is substituted with the source package name found in the first line
     # of the debian/changelog file.
-    '@PACKAGE': None,
+    # '@PACKAGE@': None,
     # This is substituted by the legal upstream version regex (capturing).
     '@ANY_VERSION@': r'[-_]?(\d[\-+\.:\~\da-zA-Z]*)',
     # This is substituted by the typical archive file extension regex
@@ -63,7 +61,7 @@ class InvalidUVersionMangle(ValueError):
     """uversionmangle is invalid"""
 
 
-class WatchFile(object):
+class WatchFile:
 
     def __init__(self, entries: Optional[List['Watch']] = None,
                  options: Optional[List[str]] = None,
@@ -91,7 +89,7 @@ class WatchFile(object):
         if newvalue is None:
             nv = name
         else:
-            nv = '%s=%s' % (name, newvalue)
+            nv = '{}={}'.format(name, newvalue)
         for i, option in enumerate(self.options):
             try:
                 key, value = option.split('=', 1)
@@ -215,7 +213,7 @@ def apply_url_mangle(expr: str, orig: str) -> str:
     return apply_sed_expr(expr, orig)
 
 
-class Release(object):
+class Release:
     """A discovered release."""
 
     def __init__(self, version, url, pgpsigurl=None):
@@ -229,7 +227,7 @@ class Release(object):
         return Version(self.version) < Version(other.version)
 
     def __repr__(self):
-        return "%s(%r, %r, pgpsigurl=%r)" % (
+        return "{}({!r}, {!r}, pgpsigurl={!r})".format(
             type(self).__name__, self.version, self.url,
             self.pgpsigurl)
 
@@ -237,7 +235,9 @@ class Release(object):
 def html_search(body, matching_pattern, base_url):
     from bs4 import BeautifulSoup
     soup = BeautifulSoup(body, 'html.parser')
-    matching_pattern = urljoin(base_url.rstrip('/') + '/', matching_pattern)
+    if '/' not in matching_pattern:
+        matching_pattern = urljoin(
+            base_url.rstrip('/') + '/', matching_pattern)
     for a in soup.find_all('a'):
         href = a.attrs.get('href')
         if not href:
@@ -245,7 +245,11 @@ def html_search(body, matching_pattern, base_url):
         href = urljoin(base_url.rstrip('/') + '/', href)
         m = pcre.match(matching_pattern, href)
         if m:
+            logging.debug('Matched pattern %r to %r', matching_pattern, href)
             yield m
+        else:
+            logging.debug(
+                'Did not match pattern %r to %r', matching_pattern, href)
 
 
 def plain_search(body, matching_pattern, base_url):
@@ -258,7 +262,18 @@ searchers = {
     }
 
 
-class Watch(object):
+def _subst(text: str, package: Union[str, Callable[[], str]]):
+    substs = dict(SUBSTITUTIONS)
+    if '@PACKAGE@' in text:
+        if callable(package):
+            package = package()
+        substs['@PACKAGE@'] = package
+    for k, v in substs.items():
+        text = text.replace(k, v)
+    return text
+
+
+class Watch:
 
     def __init__(self, url: str, matching_pattern: Optional[str] = None,
                  version: Optional[str] = None, script: Optional[str] = None,
@@ -280,7 +295,7 @@ class Watch(object):
             return apply_sed_expr(vm, version)
         except pcre.error as e:
             raise WatchSyntaxError(
-                'invalid uversionmangle %r: %s' % (vm, e)) from e
+                'invalid uversionmangle {!r}: {}'.format(vm, e)) from e
 
     def get_option(self, name):
         for option in self.options:
@@ -304,7 +319,7 @@ class Watch(object):
         if newvalue is None:
             nv = name
         else:
-            nv = '%s=%s' % (name, newvalue)
+            nv = '{}={}'.format(name, newvalue)
         for i, option in enumerate(self.options):
             try:
                 key, value = option.split('=', 1)
@@ -329,7 +344,9 @@ class Watch(object):
 
     def __repr__(self) -> str:
         return (
-            "%s(%r, matching_pattern=%r, version=%r, script=%r, opts=%r)" % (
+            ("{}({!r}, matching_pattern={!r}, "
+             "version={!r}, script={!r}, opts={!r})")
+            .format(
                 self.__class__.__name__, self.url, self.matching_pattern,
                 self.version, self.script, self.options))
 
@@ -343,11 +360,7 @@ class Watch(object):
                 other.options == self.options)
 
     def format_url(self, package: Union[str, Callable[[], str]]) -> str:
-        if '@PACKAGE@' not in self.url:
-            return self.url
-        if callable(package):
-            package = package()
-        return self.url.replace('@PACKAGE@', package)
+        return _subst(self.url, package)
 
     def discover(self, package) -> Iterator[Release]:
         from urllib.request import urlopen, Request
@@ -363,8 +376,9 @@ class Watch(object):
         logging.debug('Fetching url %s; searchmode=%s', url, searchmode)
         req = Request(url, headers={'User-Agent': user_agent})
         resp = urlopen(req)
+        assert self.matching_pattern
         for m in searchers[searchmode](
-                resp.read(), self.matching_pattern, url):
+                resp.read(), _subst(self.matching_pattern, package), url):
             # TODO(jelmer): Apply uversionmangle
             full_url = urljoin(url, m.group(0))
             try:
@@ -469,10 +483,10 @@ class WatchEditor(Editor[WatchFile, str]):
     _parsed: WatchFile
 
     def __init__(
-            self, path: str = 'debian/watch',
+            self, path: str = 'debian/watch', *,
             allow_reformatting: Optional[bool] = None,
             allow_missing: bool = False) -> None:
-        super(WatchEditor, self).__init__(
+        super().__init__(
             path, allow_reformatting=allow_reformatting)
         self.allow_missing = allow_missing
 
@@ -515,10 +529,10 @@ def main(argv):
         logging.basicConfig(level=logging.DEBUG, format='%(message)s')
     else:
         logging.basicConfig(level=logging.INFO, format='%(message)s')
-    with open('debian/watch', 'r') as f:
+    with open('debian/watch') as f:
         wf = parse_watch_file(f)
     from debian.deb822 import Deb822
-    with open('debian/control', 'r') as f:
+    with open('debian/control') as f:
         source = Deb822(f)
     uscan(wf, source['Source'])
 
